==> websi-0.3.0.tgz: package/esm/routing.js <==
import { HTTPMethod } from './mod.js';
import { isHandler, isHandlerMapping, isPipeline, compose } from './util.js';
import * as Response from './response.js';
import { Router } from './router.js';
const inferRequestValueType = (v) => {
    if (v === '') {
        return true;
    }
    else if (v === 'true') {
        return true;
    }
    else if (v === 'false') {
        return false;
    }
    else if (!isNaN(Number(v))) {
        return +v;
    }
    return v;
};
const parseBody = async (request) => {
    const { headers } = request;
    const buffer = request.body;
    if (!buffer) {
        return { params: {}, files: {} };
    }
    const contentType = headers.get('Content-Type')?.split(';')[0];
    switch (contentType) {
        case 'application/x-www-form-urlencoded': {
            const form = await request.formData();
            const params = {};
            for (const [key, value] of form) {
                params[key] = inferRequestValueType(value);
            }
            return { params, files: {} };
        }
        case 'application/json': {
            const params = await request.json();
            return { params, files: {} };
        }
        case 'multipart/form-data': {
            const form = await request.formData();
            const params = {};
            const files = {};
            for (const [key, value] of form) {
                if (value instanceof File) {
                    // TODO add mimetype? encoding?
                    files[key] = value;
                }
                else {
                    params[key] = value;
                }
            }
            return { params, files };
        }
        default:
            return { params: {}, files: {} };
    }
};
const RouteFinder = (router) => {
    return (nextHandler) => async (request, context) => {
        const { method, url } = request;
        const pathname = new URL(url).pathname;
        const data = router.find(method, pathname) || router.find('ANY', pathname);
        if (data) {
            const { handler: foundHandler, params: pathParams } = data;
            const queryParams = {};
            const { searchParams } = new URL(url);
            for (const [key, value] of searchParams) {
                queryParams[key] = inferRequestValueType(value);
            }
            const { files, params: bodyParams } = await parseBody(request.clone());
            request.params = { ...queryParams, ...pathParams, ...bodyParams };
            request.files = files;
            return await foundHandler(request, context);
        }
        else {
            return nextHandler(request, context);
        }
    };
};
export const Routing = (routes = []) => {
    const router = new Router();
    const middlewares = [];
    const add = (method, path, ...fns) => {
        const action = fns.pop();
        // pipeline is a handler composed over middlewares,
        // `action` function must be explicitly extracted from the pipeline
        // as it has different signature, thus cannot be composed
        const pipeline = fns.length === 0
            ? action
            : compose(...fns)(action);
        router.add(method, path, pipeline);
    };
    for (const [path, unit] of routes) {
        if (isHandlerMapping(unit)) {
            const { middleware = [] } = unit;
            for (const [method, handler] of Object.entries(unit)) {
                if (method in HTTPMethod) {
                    const handlerContainer = isPipeline(handler) ? handler : [handler];
                    const flow = [...middleware, ...handlerContainer];
                    add(method, path, ...flow);
                }
                // else: a key name undefined in the spec -> discarding
            }
            continue;
        }
        if (isPipeline(unit)) {
            add('ANY', path, ...unit);
            continue;
        }
        if (isHandler(unit)) {
            add('ANY', path, unit);
            continue;
        }
    }
    const pipeline = compose(...middlewares, RouteFinder(router))((_) => Response.NotFound());
    return (request, connInfo) => {
        request.params = {};
        request.files = {};
        const context = {
            connInfo,
        };
        return pipeline(request, context);
    };
};

==> websi-0.5.0.tgz: package/esm/routing.js <==
import { HTTPMethod } from './mod.js';
import { isHandler, isHandlerMapping, isPipeline, compose } from './util.js';
import * as Response from './response.js';
import { Router } from './router.js';
const inferRequestValueType = (v) => {
    if (v === '') {
        return true;
    }
    else if (v === 'true') {
        return true;
    }
    else if (v === 'false') {
        return false;
    }
    else if (!isNaN(Number(v))) {
        return +v;
    }
    return v;
};
const parseBody = async (request) => {
    const { headers } = request;
    const buffer = request.body;
    if (!buffer) {
        return { params: {}, files: {} };
    }
    const contentType = headers.get('Content-Type')?.split(';')[0];
    switch (contentType) {
        case 'application/x-www-form-urlencoded': {
            const form = await request.formData();
            const params = {};
            for (const [key, value] of form) {
                params[key] = inferRequestValueType(value);
            }
            return { params, files: {} };
        }
        case 'application/json': {
            const params = await request.json();
            return { params, files: {} };
        }
        case 'multipart/form-data': {
            const form = await request.formData();
            const params = {};
            const files = {};
            for (const [key, value] of form) {
                if (value instanceof File) {
                    // TODO add mimetype? encoding?
                    files[key] = value;
                }
                else {
                    params[key] = value;
                }
            }
            return { params, files };
        }
        default:
            return { params: {}, files: {} };
    }
};
const RouteFinder = (router) => {
    return (nextHandler) => async (request, arg1, arg2) => {
        const { method, url } = request;
        const pathname = new URL(url).pathname;
        const data = router.find(method, pathname) || router.find('ANY', pathname);
        if (data) {
            const { handler: foundHandler, params: pathParams } = data;
            const queryParams = {};
            const { searchParams } = new URL(url);
            for (const [key, value] of searchParams) {
                queryParams[key] = inferRequestValueType(value);
            }
            const { files, params: bodyParams } = await parseBody(request.clone());
            request.params = { ...queryParams, ...pathParams, ...bodyParams };
            request.files = files;
            return await foundHandler(request, arg1, arg2);
        }
        else {
            return nextHandler(request, arg1, arg2);
        }
    };
};
export const Routing = (routes = []) => {
    const router = new Router();
    const middlewares = [];
    const add = (method, path, ...fns) => {
        const action = fns.pop();
        // pipeline is a handler composed over middlewares,
        // `action` function must be explicitly extracted from the pipeline
        // as it has different signature, thus cannot be composed
        const pipeline = fns.length === 0
            ? action
            : compose(...fns)(action);
        router.add(method, path, pipeline);
    };
    for (const [path, unit] of routes) {
        if (isHandlerMapping(unit)) {
            const { middleware = [] } = unit;
            for (const [method, handler] of Object.entries(unit)) {
                if (method in HTTPMethod) {
                    const handlerContainer = isPipeline(handler) ? handler : [handler];
                    const flow = [...middleware, ...handlerContainer];
                    add(method, path, ...flow);
                }
                // else: a key name undefined in the spec -> discarding
            }
            continue;
        }
        if (isPipeline(unit)) {
            add('ANY', path, ...unit);
            continue;
        }
        if (isHandler(unit)) {
            add('ANY', path, unit);
            continue;
        }
    }
    const NotFound = (_) => Response.NotFound();
    const pipeline = compose(...middlewares, RouteFinder(router))(NotFound);
    // deno-lint-ignore no-explicit-any
    return (req, arg1, arg2) => {
        const request = req;
        request.params = {};
        request.files = {};
        return pipeline(request, arg1, arg2);
    };
};
